noise computes the noise of a linear transfer function model.
noise(tfm, ...)# S3 method for tfm
noise(tfm, y = NULL, diff = TRUE, exp = FALSE, ...)
an object of the class tfm.
additional arguments.
output of the TF model if it is different to that of the
tfm object.
logical. If TRUE, the noise is differenced with the "i" operator of the univariate model of the noise.
logical. If TRUE, the antilog transformation is applied.
A "ts" object.